from setuptools import setup, find_packages

setup(
    name='data_Javharbek',
    version='0.3',
    packages=find_packages(),
    install_requires=[
    ],
    author='Javharbek',
    author_email='jakharbek@gmail.com',
    description='DATA',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
